@@ -46,6 +46,19 @@ class NonSlotted(abc.ABCMeta):
                                                            attributes,
                                                          **kwargs)
 
+class Format(abc.ABC):
+    
+    """ An abstract class representing something that formats something
+        else. It only offers the one abstract method, “render(…)” at
+        this time.
+    """
+    __slots__ = tuple()
+    
+    @abstract
+    def render(self, string):
+        """ Render a string with respect to the Format instance. """
+        ...
+
 class Cloneable(abc.ABC):
     
     """ An abstract class representing something “clonable.” A cloneable
@@ -113,7 +126,7 @@ class ReprWrapper(abc.ABC):
         from clu.repr import typename_hexid
         cnm, hxa = typename_hexid(self)
         rpr = self.inner_repr()
-        return f"{cnm}({rpr}) @ {hxa}"
+        return f"{cnm}({rpr}) {consts.REPR_DELIMITER} {hxa}"
 
 class SlottedRepr(ReprWrapper, metaclass=Slotted):
     
@@ -180,30 +193,30 @@ class ValueDescriptor(Descriptor):
                isinstance(self.value, bytes) and self.value.decode(ENCODING) or \
                                             repr(self.value)
 
-class Prefix(Slotted):
+class BasePath(Slotted):
     
-    """ A metaclass to assign a “prefix” class property,
-        extracted from a “prefix” class keyword, to a new
+    """ A metaclass to assign a “basepath” class property,
+        extracted from a “basepath” class keyword, to a new
         slotted type. 
     """
     
     @classmethod
-    def __prepare__(metacls, name, bases, prefix="/", **kwargs):
-        """ Remove the “prefix” class keyword before calling up """
-        return super(Prefix, metacls).__prepare__(name, bases, **kwargs)
+    def __prepare__(metacls, name, bases, basepath="/", **kwargs):
+        """ Remove the “basepath” class keyword before calling up """
+        return super(BasePath, metacls).__prepare__(name, bases, **kwargs)
     
-    def __new__(metacls, name, bases, attributes, prefix="/", **kwargs):
+    def __new__(metacls, name, bases, attributes, basepath="/", **kwargs):
         """ Override for `Slotted.__new__(…)` setting up a
-            derived slotted class that pulls from a “prefix”
+            derived slotted class that pulls from a “basepath”
             with the requisite methods defined for access.
         """
-        if 'prefix' not in attributes:
-            attributes['prefix'] = ValueDescriptor(prefix)
+        if 'basepath' not in attributes:
+            attributes['basepath'] = ValueDescriptor(basepath)
         
-        return super(Prefix, metacls).__new__(metacls, name,
-                                                       bases,
-                                                       attributes,
-                                                     **kwargs)
+        return super(BasePath, metacls).__new__(metacls, name,
+                                                         bases,
+                                                         attributes,
+                                                       **kwargs)
 
 class AppName(abc.ABC):
     
@@ -214,6 +227,8 @@ class AppName(abc.ABC):
         """ Translate the “appname” class-keyword into an “appname” read-only
             descriptor value
         """
+        if 'appspace' in kwargs:
+            del kwargs['appspace']
         super(AppName, cls).__init_subclass__(**kwargs)
         cls.appname = ValueDescriptor(appname)
     
@@ -270,11 +285,12 @@ else:
         pass
 
 __all__ = ('Slotted', 'NonSlotted',
+           'Format',
            'Cloneable',
            'ReprWrapper',
            'SlottedRepr', 'MappingViewRepr',
            'Descriptor', 'ValueDescriptor',
-           'Prefix', 'AppName',
+           'BasePath', 'AppName',
            'ManagedContext', 'AsyncManagedContext')
 
 __dir__ = lambda: list(__all__)
