@@ -231,7 +231,10 @@ class ChainMap(collections.abc.MutableMapping,
     
     def __getitem__(self, key):
         from clu.predicates import try_items
-        return try_items(key, *self.maps, default=None) or self.__missing__(key)
+        try:
+            return try_items(key, *self.maps)
+        except KeyError:
+            return self.__missing__(key)
     
     def __len__(self):
         return len(set(iterchain(map.keys() for map in self.maps)))
@@ -245,6 +248,9 @@ class ChainMap(collections.abc.MutableMapping,
     def __bool__(self):
         return any(self.maps)
     
+    def __str__(self):
+        return cmshortrepr(self)
+    
     def __repr__(self):
         return cmrepr(self)
     
@@ -347,7 +353,7 @@ class ChainMap(collections.abc.MutableMapping,
         # return dict(iterchain(map.items() for map in self.maps))
     
     def clone(self, deep=False, memo=None):
-        """ Return a cloned copy of the ChainMap """
+        """ Return a cloned copy of the ChainMap instance """
         from copy import copy, deepcopy
         cls = type(self)
         if not deep:
