@@ -30,7 +30,7 @@ except ImportError:
 
 from clu.constants import consts
 from clu.extending import Extensible
-from clu.naming import nameof, moduleof, dotpath_split, dotpath_join, qualified_name
+from clu.naming import nameof, dotpath_split, dotpath_join, qualified_name
 from clu.predicates import anyattrs, attr, attr_search, item_search, mro, tuplize
 from clu.repr import stringify
 from clu.typespace import Namespace, types
@@ -97,9 +97,9 @@ class MetaRegistry(Extensible):
         """ Type repr definition for class-based modules and ancestors """
         qualname = getattr(cls, 'qualname', None)
         if not qualname:
-            module = moduleof(cls)
-            return f"<class-module ancestor type “{module}.{cls.__name__}”>"
-        return f"<class-module “{cls.qualname}”>"
+            qname = qualified_name(cls) # DIFFERENT!!! CONFUSING!!!!
+            return f"<class-module ancestor “{qname}”>"
+        return f"<class-module “{qualname}”>"
     
     @staticmethod
     def unregister(appname, qualified_name):
@@ -255,6 +255,11 @@ class FinderBase(clu.abstract.AppName,
     specs = {}
     cache = zict.LRU(64, specs)
     
+    @classmethod
+    def spec(cls, fullname):
+        out = cls.cache[fullname] = ModuleSpec(fullname, cls.loader)
+        return out
+    
     @classmethod
     def find_spec(cls, fullname, path=None, target=None):
         """ Return a ModuleSpec for a qualified module name –
@@ -263,9 +268,13 @@ class FinderBase(clu.abstract.AppName,
         """
         if fullname in cls.cache:
             return cls.cache[fullname]
-        if cls.appname == fullname.split(consts.QUALIFIER).pop(0):
-            out = cls.cache[fullname] = ModuleSpec(fullname, cls.loader)
-            return out
+        if consts.QUALIFIER not in fullname:
+            if fullname == cls.appname:
+                return cls.spec(fullname)
+            return None
+        appname, appspace, *remainders = fullname.split(consts.QUALIFIER, 2)
+        if appname == cls.appname and appspace in polymers.all_appspaces():
+            return cls.spec(fullname)
         return None
     
     @classmethod
@@ -325,7 +334,13 @@ class LoaderBase(clu.abstract.AppName,
                 docstr = inspect.getdoc(ModuleClass)
                 module = ModuleClass(modulename, doc=docstr)
                 return module
-            return self.package_module(spec.name)
+            else:
+                if spec.name == cls.appname:
+                    return self.package_module(spec.name)
+                appname, appspace, *remainders = spec.name.split(consts.QUALIFIER, 2)
+                if appname == cls.appname and appspace in polymers.all_appspaces():
+                    return self.package_module(spec.name)
+            return None
         return None
     
     def exec_module(self, module):
@@ -481,8 +496,9 @@ class MetaModule(MetaRegistry):
         if cls.appname is not None and not name.endswith('Module'):
             if ExporterRegistry.has_appname(cls.appname):
                 ExporterClass = ExporterRegistry[cls.appname]
-                setattr(cls, consts.EXPORTER_NAME,
-                             ExporterClass(dotpath=cls.qualname))
+                if not hasattr(cls, consts.EXPORTER_NAME):
+                    setattr(cls, consts.EXPORTER_NAME,
+                                 ExporterClass(dotpath=cls.qualname))
                 
                 # Invoke all of our argument sinks against the
                 # Exporter instance’s “export(…)” function:
@@ -511,7 +527,7 @@ class ModuleBase(Package, Registry, metaclass=MetaModule):
         is “app” – all class-based modules are therefore imported
         from “clu.app”, á la:
             
-            from clu.app import class_based_module
+            >>> from clu.app import class_based_module
         
         Note that class-based modules are forbidden from using
         the “__slots__” class attribute – the module class’ metaclass
@@ -662,6 +678,10 @@ class PolymerType(dict):
         if not self.get(appname, None):
             raise ValueError(f"no PerApp instance for appname: {appname}")
         return self[appname].loader
+    
+    def all_appspaces(self):
+        for key in self.keys():
+            yield from self[key].appspaces()
 
 # The per-appname subtype registry dictionary:
 polymers = PolymerType()
@@ -710,7 +730,7 @@ def initialize_types(appname, appspace='app'):
         You use ‘initialize_types(…)’ in one of your own app’s modules
         like so:
         
-            Module, Finder, Loader = initialize_types('myappname')
+            >>> Module, Finder, Loader = initialize_types('myappname')
         
         … if you insert that line of code in a module of yours called,
         say, “myappname/modules.py” you could then either a) proceed
@@ -871,29 +891,29 @@ class ProxyModule(Module):
         
         Here’s a basic example of a ProxyModule definition:
         
-            overrides = dict(…)
-            from yodogg.app import base_module
-            from yodogg.utils import misc as second_module
-            from yodogg.utils.functions import default_factory
+            >>> overrides = dict(…)
+            >>> from yodogg.app import base_module
+            >>> from yodogg.utils import misc as second_module
+            >>> from yodogg.utils.functions import default_factory
             
-            class myproxy(ProxyModule):
-                targets = (overrides, base_module,
-                                    second_module,
-                                  default_factory)
+            >>> class myproxy(ProxyModule):
+            >>>     targets = (overrides, base_module,
+            >>>                         second_module,
+            >>>                       default_factory)
         
         … which after defining that, you’d use it like so – assuming your app
         is called “yodogg” with a default “app” appspace (see “ModuleBase” for
         more on these terms):
         
-            from yodogg.app import myproxy
-            myproxy.attrib # searches overrides, base_module and second_module
-                           # in sequence, looking for the 'attrib' value
-            dir(myproxy)   # returns a list of the union of available stuff,
-                           # across the proxy modules’ targets
-            myproxy.NOATTR # unknown attributes will be forwarded to each
-                           # module-level “__getattr__(…)” function, dictionary
-                           # “__missing__(…)” method, or callable target found,
-                           # in turn, if the attribute search proves exhaustive
+            >>> from yodogg.app import myproxy
+            >>> myproxy.attrib # searches overrides, base_module and second_module
+            >>>                # in sequence, looking for the 'attrib' value
+            >>> dir(myproxy)   # returns a list of the union of available stuff,
+            >>>                # across the proxy modules’ targets
+            >>> myproxy.NOATTR # unknown attributes will be forwarded to each
+            >>>                # module-level “__getattr__(…)” function, dictionary
+            >>>                # “__missing__(…)” method, or callable target found,
+            >>>                # in turn, if the attribute search proves exhaustive
         
         … you can, in the modules’ definition, include other stuff besides the
         class-level “targets” tuple; other elements added to the proxy will
