@@ -74,6 +74,14 @@ that pathological 0.001-percent case… well, that may be an
 indication that you need to change something, dogg.
 """
 
+@export
+def main_module_name(basepath=None):
+    import __main__
+    if basepath is None:
+        basepath = BASEPATH
+    return path_to_dotpath(__main__.__file__,
+                           relative_to=basepath)
+
 @export
 def nameof(thing, default=NoDefault):
     """ Get the name of a thing, according to its attributes,
@@ -106,6 +114,9 @@ def moduleof(thing, default=NoDefault):
                  search_for_module(thing)) or \
              determine_module(thing)
     
+    if result == '__main__':
+        return main_module_name()
+    
     if default is NoDefault:
         return result
     return result or default
@@ -344,17 +355,17 @@ def duplicate(target, name, gs=None, **attributes):
     if target.__doc__:
         function.__doc__         = inspect.getdoc(target)
     
-    # Replace only the relevant part of the qualname:
-    if allpyattrs(target, 'qualname', 'name'):
-        qnm, nm = pyattrs(target, 'qualname', 'name')
-        function.__qualname__    = qnm.replace(nm, name)
-    
     # Copy the “lambda_name”, if present:
     if pyattr(target, 'lambda_name'):
         function.__lambda_name__ = target.__lambda_name__
     elif target.__name__ in (λ, φ):
         function.__lambda_name__ = target.__name__
     
+    # Replace only the relevant part of the qualname:
+    if allpyattrs(target, 'qualname', 'name'):
+        qnm, nm = pyattrs(target, 'qualname', 'name')
+        function.__qualname__    = qnm.replace(nm, name)
+    
     # Duplicate the wrapped function, if present:
     if ΛΛ(pyattr(target, 'wrapped')):
         function.__wrapped__ = duplicate(unwrap(target),
