@@ -2,26 +2,31 @@
 from __future__ import print_function
 from collections import namedtuple as NamedTuple
 
+import abc
 import colorama
-# colorama.init()
-
+import clu.abstract
 import inspect
-import sys
 import textwrap
+import sys
 import zict
 
+abstract = abc.abstractmethod
+
 from clu.constants.consts import DEBUG, ENCODING, SEPARATOR_WIDTH
 from clu.constants.polyfills import Enum, unique, auto
-from clu.predicates import attr, attrs, mro
+from clu.predicates import mro, or_none
 from clu.typology import dict_types, isstring, isbytes
 from clu.fs.misc import re_matcher
 from clu.naming import nameof, qualified_name
 from clu.enums import alias, AliasingEnumMeta
+from clu.stdio import std, linebreak, flush_all
 from clu.exporting import Exporter
 
 exporter = Exporter(path=__file__)
 export = exporter.decorator()
 
+# colorama.init()
+
 print_separator = lambda filler='-': print(filler * SEPARATOR_WIDTH)
 evict_announcer = lambda key, value: print(f"Cache dropped: {key}")
 
@@ -86,6 +91,9 @@ class ANSI(AliasingEnumMeta):
         def init_method(self, value):
             self.code = str(getattr(type(self).source, self.name, ''))
         
+        def bool_method(self):
+            return bool(self.to_string())
+        
         def str_method(self):
             return self.to_string()
         
@@ -106,6 +114,7 @@ class ANSI(AliasingEnumMeta):
         attributes['cache']     = CacheDescriptor()
         attributes['source']    = SourceDescriptor()
         attributes['__init__']  = init_method
+        attributes['__bool__']  = bool_method
         attributes['__str__']   = str_method
         attributes['__add__']   = add_method
         attributes['__doc__']   = inspect.cleandoc(doc_string)
@@ -144,7 +153,9 @@ class ANSI(AliasingEnumMeta):
     
     def convert(cls, specifier):
         """ Convert a specifier of unknown type to an enum or alias member """
-        if cls.is_ansi(specifier):
+        if specifier is None:
+            return cls.NOTHING
+        elif cls.is_ansi(specifier):
             return specifier                        # Already an ANSI type, return it
         if isstring(specifier):
             return cls.for_name(specifier)          # Match by name, decoding if necessary
@@ -187,7 +198,7 @@ class Text(ANSIBase, metaclass=ANSI, source=colorama.Fore):
     PINK                = alias(LIGHTRED_EX)
     LIGHTWHITE          = alias(LIGHTWHITE_EX)
     LIGHTYELLOW         = alias(LIGHTYELLOW_EX)
-    NOTHING             = auto()
+    NOTHING             = auto() # None
     RESET               = auto()
 
 @unique
@@ -219,7 +230,7 @@ class Background(ANSIBase, metaclass=ANSI, source=colorama.Back):
     PINK                = alias(LIGHTRED_EX)
     LIGHTWHITE          = alias(LIGHTWHITE_EX)
     LIGHTYELLOW         = alias(LIGHTYELLOW_EX)
-    NOTHING             = auto()
+    NOTHING             = auto() # None
     RESET               = auto()
 
 @unique
@@ -228,20 +239,60 @@ class Weight(ANSIBase, metaclass=ANSI, source=colorama.Style):
     BRIGHT              = auto()
     DIM                 = auto()
     NORMAL              = auto()
-    NOTHING             = auto()
+    NOTHING             = auto() # None
     RESET_ALL           = auto()
     RESET               = alias(RESET_ALL)
 
 FIELDS = ('text', 'background', 'weight')
 fields = frozenset(FIELDS)
 
-ANSIFormatBase = NamedTuple('ANSIFormatBase', FIELDS, module=__file__)
+ANSIFormatBase = NamedTuple('ANSIFormatBase', FIELDS)
 
 @export
-class ANSIFormat(ANSIFormatBase):
+class ANSIFormat(clu.abstract.Format,
+                 clu.abstract.Cloneable,
+                 clu.abstract.ReprWrapper,
+                 ANSIFormatBase):
     
+    """ The formatter class for ANSI markup codes. """
+    
+    instances = {}
     RESET_ALL = Weight.RESET_ALL.to_string()
     
+    @classmethod
+    def pre_existing(cls, text, background, weight):
+        """ Boolean function to test the instance cache for the presence of
+            an ANSIFormat instance matching a given text/background/weight
+        """
+        return hash((text, background, weight)) in (hash(key) for key in cls.instances.keys())
+    
+    @classmethod
+    def instance_for(cls, text, background, weight):
+        """ Return an instance matching a given text/background/weight from
+            the instance cache, or – if such an instance can’t be found –
+            raise a descriptive KeyError to indicate failure
+        """
+        h = hash((text, background, weight))
+        for key in cls.instances.keys():
+            if hash(key) == h:
+                return cls.instances[key]
+        raise KeyError(f"no instance found for text/background/weight: {text!s}, {background!s}, {weight!s}")
+    
+    @classmethod
+    def get_or_create(cls, text, background, weight):
+        """ Return an instance matching the given text/background/weight.
+            
+            Any such instance found in the cache will be summarily returned;
+            otherwise, a new instance is created and ensconced in the cache
+            before finally ending up as the return itself.
+        """
+        try:
+            out = cls.instance_for(text, background, weight)
+        except KeyError:
+            out = super().__new__(cls, text, background, weight)
+            cls.instances[(text, background, weight)] = out
+        return out
+    
     @classmethod
     def from_dict(cls, format_dict):
         """ Instantiate an ANSIFormat with a dict of related ANSI values –
@@ -255,8 +306,9 @@ class ANSIFormat(ANSIFormatBase):
         """ Return the ANSI format primitives as a dict """
         out = {}
         for field in FIELDS:
-            if getattr(self, field, None) is not None:
-                out[field] = getattr(self, field)
+            fieldval = or_none(self, field)
+            if fieldval is not None:
+                out[field] = fieldval
         return out
     
     def to_tuple(self):
@@ -268,11 +320,11 @@ class ANSIFormat(ANSIFormatBase):
     def to_string(self):
         """ Build up an initial ANSI format string based on values present """
         out = ""
-        if self.text is not None:
+        if bool(self.text):
             out += str(self.text)
-        if self.background is not None:
+        if bool(self.background):
             out += str(self.background)
-        if self.weight is not None:
+        if bool(self.weight):
             out += str(self.weight)
         return out
     
@@ -280,7 +332,7 @@ class ANSIFormat(ANSIFormatBase):
                                       background=Background.NOTHING,
                                       weight=Weight.NORMAL):
         """ Instantiate an ANSIFormat, populating its fields per args """
-        if from_value is not None:
+        if from_value not in (None, ''):
             if type(from_value) is cls:
                 if all(field is None for field in from_value):
                     return from_value
@@ -295,17 +347,17 @@ class ANSIFormat(ANSIFormatBase):
                 text = str(from_value, encoding=ENCODING)
             elif ANSIBase.is_ansi(from_value):
                 text = from_value
-        instance = super(ANSIFormat, cls).__new__(cls, Text.convert(text),
-                                                       Background.convert(background),
-                                                       Weight.convert(weight))
+        instance = cls.get_or_create(Text.convert(text),
+                               Background.convert(background),
+                                   Weight.convert(weight))
         return instance
     
     @classmethod
     def null(cls):
-        instance = super(ANSIFormat, cls).__new__(cls, None,
-                                                       None,
-                                                       None)
-        return instance
+        """ Retrieve a “null instance” of ANSIFormat – one with all of its
+            formatting directives unspecified.
+        """
+        return cls.get_or_create(None, None, None)
     
     def __str__(self):
         """ Stringify the ANSIFormat (q.v. “to_string(…)” supra.) """
@@ -324,9 +376,20 @@ class ANSIFormat(ANSIFormatBase):
            “background”, and “weight” fields are all set to None; otherwise it’s
             a Truthy value in boolean contexts
         """
-        return not (self.text is None and \
-                    self.background is None and \
-                    self.weight is None)
+        return not (bool(self.text) and \
+                    bool(self.background) and \
+                    bool(self.weight))
+    
+    def clone(self, deep=False, memo=None):
+        # N.B. deep-cloning is meaningless here as everything’s an enum value:
+        return type(self)(text=self.text,
+                          background=self.background,
+                          weight=self.weight)
+    
+    def inner_repr(self):
+        return f"text={self.text and self.text.name or 'NOTHING'}, " \
+               f"background={self.background and self.background.name or 'NOTHING'}, " \
+               f"weight={self.weight and self.weight.name or 'NOTHING'}"
     
     def render(self, string):
         """ Render a string appropriately marked up with the ANSI formatting
@@ -337,38 +400,64 @@ class ANSIFormat(ANSIFormatBase):
         suffix = prefix and self.RESET_ALL or ""
         return f"{prefix}{string!s}{suffix}"
 
-# Determine the proper output streams for the current I/O environment:
-sestream = attr(sys, '__stderr__', 'stderr')
-sostream = attr(sys, '__stdout__', 'stdout')
-streams = attrs(sys, '__stdout__', 'stdout')
-
-linebreak = lambda: print(file=sostream)
-flush_all = lambda: (stream.flush() for stream in streams)
+@export
+class NonFormat(clu.abstract.Format):
+    
+    """ A “format” type whose “render(…)” method is a no-op. """
+    
+    def __init__(self, *args):
+        pass
+    
+    def render(self, string):
+        """ Return a string, unchanged """
+        return string
 
 @export
-def print_ansi(text, color='', file=sostream):
+def print_ansi(text, color=None, file=std.OUT):
     """ print_ansi(…) → Print text in ANSI color, using optional inline markup
                         from `colorama` for terminal color-escape delimiters """
-    fmt = ANSIFormat(color)
+    FormatClass = file.isatty() and ANSIFormat or NonFormat
+    fmt = FormatClass(color)
     for line in text.splitlines():
         print(fmt.render(line), sep='', end='\n', file=file)
+    return None
 
 @export
-def print_ansi_centered(text, color='',
-                              filler='•',
-                              width=SEPARATOR_WIDTH,
-                              file=sostream):
+def print_ansi_centered(text=None, color=None,
+                                   filler='•',
+                                   width=None,
+                                   file=std.OUT):
     """ print_ansi_centered(…) → Print a string to the terminal, centered
                                  and bookended with asterisks """
+    if text is None:
+        return print_ansi(filler * (width or SEPARATOR_WIDTH), color=color, file=file)
     message = f" {text.strip()} "
-    print_ansi(message.center(width, filler), color=color, file=file)
+    return print_ansi(message.center(width or SEPARATOR_WIDTH, filler), color=color, file=file)
 
-INITIAL     = '  ¶ '
-SUBSEQUENT  = '    '
+LIGHTBLUE   = ANSIFormat(text=Text.LIGHTBLUE)
+DARKGRAY    = ANSIFormat(text=Text.GRAY)
+RED         = ANSIFormat(text=Text.RED)
+NOTHING     = ANSIFormat()
+
+chevron     = RED.render("»")
+colon       = DARKGRAY.render(":")
+
+@export
+def print_ansi_name_value(name, value, most=25,
+                                    pilcrow=chevron,
+                                     equals=colon,
+                                  namecolor=LIGHTBLUE,
+                                 valuecolor=DARKGRAY,
+                                       file=std.OUT):
+    """ Format and colorize each segment of the name/value output """
+    key = namecolor.render(f" {name} ".rjust(most+2))
+    val = valuecolor.render(f" {value!s}")
+    return print_ansi(pilcrow + key
+                     + equals + val, color=NOTHING)
 
 # Regex boolean predicates for matching marked (or bulleted) paragraphs:
-para_mark_matcher = re_matcher(r"^[0-9+•⌀\<\>«»→\#¬†‡¶§±–\-\+\*]+")
-para_line_matcher = re_matcher(r"^[+•⌀\<\>«»→\#¬†‡¶§±–\-\+\*]+")
+para_mark_matcher = re_matcher(r"^\s*[0-9+•⌀\<\>«»→\#¬†‡¶§±–\-\+\*]+")
+para_line_matcher = re_matcher(r"^\s*[+•⌀\<\>«»→\#¬†‡¶§±–\-\+\*]+")
 
 @export
 def paragraphize(doc):
@@ -384,8 +473,27 @@ def paragraphize(doc):
                 lines[idx] += " "
     return ''.join(lines).splitlines()
 
-# Pre-calculate width
-WIDTH = int(SEPARATOR_WIDTH * 0.8)
+@export
+def highlight(code_string, language='json',
+                             markup='terminal256',
+                              style='paraiso-dark',
+                             isatty=True):
+    """ Highlight a code string with inline 256-color ANSI markup,
+        using `pygments.highlight(…)` and the “Paraiso Dark” theme
+    """
+    if not isatty:
+        return code_string
+    import pygments, pygments.lexers, pygments.formatters
+    LexerCls = pygments.lexers.find_lexer_class_by_name(language)
+    formatter = pygments.formatters.get_formatter_by_name(markup, style=style)
+    return pygments.highlight(code_string, lexer=LexerCls(), formatter=formatter)
+
+# Margin-dwelling legibility symbols:
+INITIAL         = '  ¶ '
+SUBSEQUENT      = '    '
+
+# Pre-calculate eighty-percent width:
+EIGHTY_PERCENT  = int(SEPARATOR_WIDTH * 0.8)
 
 @export
 def ansidoc(*things):
@@ -398,12 +506,25 @@ def ansidoc(*things):
         # Process each things’ name and doc
         thingname = nameof(thing)
         doc = inspect.getdoc(thing) or "«¡no docstring found!»"
+        sig = inspect.signature(thing) or ""
         paras = paragraphize(doc)
         
         # Print the ANSI header
         print_ansi_centered(f"__doc__ for “{thingname}”", color=Text.CYAN)
         linebreak()
         
+        # Code-highlight, format and print the thing and its call-signature:
+        print(highlight(textwrap.fill(f"{thingname}{sig}",
+                        initial_indent=INITIAL,
+                        subsequent_indent=SUBSEQUENT,
+                        replace_whitespace=True,
+                        placeholder="…",
+                        tabsize=4,
+                        width=EIGHTY_PERCENT), language='python',
+                                               isatty=std.OUT.isatty()),
+                                               sep='', end='\n',
+                                               file=std.OUT)
+        
         # Format and print each paragraph
         for para in paras:
             if para:
@@ -415,33 +536,18 @@ def ansidoc(*things):
                                               drop_whitespace=True,
                                                   placeholder='…',
                                                       tabsize=4,
-                                                        width=WIDTH),
+                                                        width=EIGHTY_PERCENT),
                                                         color=Text.GRAY)
             else:
                 linebreak()
         
         # FLush and cease output
         linebreak()
-        linebreak()
         print()
         flush_all()
 
-@export
-def highlight(code_string, language='json',
-                             markup='terminal256',
-                              style='paraiso-dark'):
-    """ Highlight a code string with inline 256-color ANSI markup,
-        using `pygments.highlight(…)` and the “Paraiso Dark” theme
-    """
-    import pygments, pygments.lexers, pygments.formatters
-    LexerCls = pygments.lexers.find_lexer_class_by_name(language)
-    formatter = pygments.formatters.get_formatter_by_name(markup, style=style)
-    return pygments.highlight(code_string, lexer=LexerCls(), formatter=formatter)
-
-export(print_separator,     name='print_separator', doc="print_separator(filler_char='-') → print filler_char TERMINAL_WIDTH times")
+export(print_separator,     name='print_separator', doc="print_separator(filler='-') → print ‘filler’ character consts.SEPARATOR_WIDTH times")
 export(evict_announcer,     name='evict_announcer', doc="evict_announcer(key, value) → print a debug trace message about the key and value")
-export(linebreak,           name='linebreak',       doc="linebreak() → print a newline to `stdout`")
-export(flush_all,           name='flush_all',       doc="flush_all() → flush the output buffers of all possible `stdout` candidates")
 
 # NO DOCS ALLOWED:
 export(Text)
@@ -449,4 +555,23 @@ export(Background)
 export(Weight)
 
 # Assign the modules’ `__all__` and `__dir__` using the exporter:
-__all__, __dir__ = exporter.all_and_dir()
\ No newline at end of file
+__all__, __dir__ = exporter.all_and_dir()
+
+
+def test():
+    
+    from clu.testing.utils import inline
+    
+    @inline
+    def test_one():
+        print_ansi('yo dogg')
+        print_ansi_centered('I heard you like non-ANSI-formatted text')
+    
+    @inline
+    def test_two():
+        ansidoc(ansidoc)
+    
+    return inline.test(10)
+
+if __name__ == '__main__':
+    sys.exit(test())
\ No newline at end of file
