@@ -7,15 +7,43 @@ import contextlib
 import os
 import pytest
 
+from clu.testing.utils import countfiles
 from clu.fs.filesystem import Directory
 
 class TestFsFilesystem(object):
     
     """ Run the tests for the clu.fs.filesystem module. """
     
+    def test_suffixes(self, dirname):
+        from clu.fs.misc import extension
+        
+        histo = dirname.suffix_histogram()
+        keys = tuple(histo.keys()) # same as dirname.suffixes()
+        
+        for suffix in dirname.suffixes():
+            assert suffix in histo
+            assert suffix in keys
+        
+        for root, dirs, files in dirname.walk():
+            for filename in files:
+                ext = extension(filename)
+                if ext:
+                    assert ext in histo
+                    assert ext in keys
+    
+    def test_suffix_histogram(self, dirname):
+        
+        histo = dirname.suffix_histogram()
+        
+        assert len(histo)
+        assert 'py' in histo
+        assert 'pyc' in histo
+        
+        for suffix in histo.keys():
+            assert histo[suffix] == countfiles(dirname, suffix=suffix)
+    
     def test_flatten(self, datadir,
                            temporarydir):
-        from clu.testing.utils import countfiles
         from clu.typology import isvalidpathlist
         
         # target directory should not already exist:
@@ -47,7 +75,6 @@ class TestFsFilesystem(object):
     
     def test_flatten_with_suffix_filter(self, datadir,
                                               temporarydir):
-        from clu.testing.utils import countfiles
         from clu.typology import isvalidpathlist
         
         # target directory should not already exist:
@@ -80,7 +107,6 @@ class TestFsFilesystem(object):
     
     def test_flatten_with_new_suffix(self, datadir,
                                            temporarydir):
-        from clu.testing.utils import countfiles
         from clu.typology import isvalidpathlist
         
         # target directory should not already exist:
@@ -114,7 +140,6 @@ class TestFsFilesystem(object):
     
     def test_flatten_with_new_suffix_and_suffix_filter(self, datadir,
                                                              temporarydir):
-        from clu.testing.utils import countfiles
         from clu.typology import isvalidpathlist
         
         # target directory should not already exist:
@@ -148,7 +173,6 @@ class TestFsFilesystem(object):
             assert os.path.basename(f) in destination
     
     def test_zip_archive_temporaryname(self, dirname, temporaryname):
-        from clu.testing.utils import countfiles
         
         # Ensure the “data” directory has something
         # in it, of which we can make use:
@@ -171,7 +195,6 @@ class TestFsFilesystem(object):
     
     def test_zip_archive(self, dirname):
         from clu.fs.filesystem import temporary
-        from clu.testing.utils import countfiles
         
         # Ensure the “data” directory has something
         # in it, of which we can make use:
@@ -292,7 +315,6 @@ class TestFsFilesystem(object):
     def test_rm_rf(self, temporarydir):
         # Also involves `write_to_path(…)` and `Directory.walk()`
         from clu.fs.filesystem import write_to_path, rm_rf
-        from clu.testing.utils import countfiles
         
         # Make subdirectories:
         dd = temporarydir.subdirectory('yo')
