@@ -361,9 +361,9 @@ class TestImporting(object):
         from clu.fs import pypath
         
         # Ensure “sys.path” contains the “yodogg” package:
-        prefix = dirname.subdirectory('yodogg')
-        assert prefix.exists
-        pypath.enhance(prefix)
+        basepath = dirname.subdirectory('yodogg')
+        assert basepath.exists
+        pypath.enhance(basepath)
         
         # Bring in the package-specific Module subclass
         from yodogg.config import Module
